@@ -52,12 +52,25 @@ class UpgradeNote(proto.Message):
             metadata about the Windows update.
     """
 
-    package = proto.Field(proto.STRING, number=1,)
-    version = proto.Field(proto.MESSAGE, number=2, message=g_package.Version,)
+    package = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    version = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=g_package.Version,
+    )
     distributions = proto.RepeatedField(
-        proto.MESSAGE, number=3, message="UpgradeDistribution",
+        proto.MESSAGE,
+        number=3,
+        message="UpgradeDistribution",
+    )
+    windows_update = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="WindowsUpdate",
     )
-    windows_update = proto.Field(proto.MESSAGE, number=4, message="WindowsUpdate",)
 
 
 class UpgradeDistribution(proto.Message):
@@ -84,10 +97,22 @@ class UpgradeDistribution(proto.Message):
             The cve tied to this Upgrade.
     """
 
-    cpe_uri = proto.Field(proto.STRING, number=1,)
-    classification = proto.Field(proto.STRING, number=2,)
-    severity = proto.Field(proto.STRING, number=3,)
-    cve = proto.RepeatedField(proto.STRING, number=4,)
+    cpe_uri = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    classification = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    severity = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    cve = proto.RepeatedField(
+        proto.STRING,
+        number=4,
+    )
 
 
 class WindowsUpdate(proto.Message):
@@ -128,8 +153,14 @@ class WindowsUpdate(proto.Message):
                 The revision number of the update.
         """
 
-        update_id = proto.Field(proto.STRING, number=1,)
-        revision = proto.Field(proto.INT32, number=2,)
+        update_id = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        revision = proto.Field(
+            proto.INT32,
+            number=2,
+        )
 
     class Category(proto.Message):
         r"""The category to which the update belongs.
@@ -141,17 +172,45 @@ class WindowsUpdate(proto.Message):
                 The localized name of the category.
         """
 
-        category_id = proto.Field(proto.STRING, number=1,)
-        name = proto.Field(proto.STRING, number=2,)
+        category_id = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        name = proto.Field(
+            proto.STRING,
+            number=2,
+        )
 
-    identity = proto.Field(proto.MESSAGE, number=1, message=Identity,)
-    title = proto.Field(proto.STRING, number=2,)
-    description = proto.Field(proto.STRING, number=3,)
-    categories = proto.RepeatedField(proto.MESSAGE, number=4, message=Category,)
-    kb_article_ids = proto.RepeatedField(proto.STRING, number=5,)
-    support_url = proto.Field(proto.STRING, number=6,)
+    identity = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=Identity,
+    )
+    title = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    categories = proto.RepeatedField(
+        proto.MESSAGE,
+        number=4,
+        message=Category,
+    )
+    kb_article_ids = proto.RepeatedField(
+        proto.STRING,
+        number=5,
+    )
+    support_url = proto.Field(
+        proto.STRING,
+        number=6,
+    )
     last_published_timestamp = proto.Field(
-        proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=7,
+        message=timestamp_pb2.Timestamp,
     )
 
 
@@ -179,10 +238,25 @@ class UpgradeOccurrence(proto.Message):
             metadata about the Windows update.
     """
 
-    package = proto.Field(proto.STRING, number=1,)
-    parsed_version = proto.Field(proto.MESSAGE, number=3, message=g_package.Version,)
-    distribution = proto.Field(proto.MESSAGE, number=4, message="UpgradeDistribution",)
-    windows_update = proto.Field(proto.MESSAGE, number=5, message="WindowsUpdate",)
+    package = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    parsed_version = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=g_package.Version,
+    )
+    distribution = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="UpgradeDistribution",
+    )
+    windows_update = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message="WindowsUpdate",
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
