@@ -23,7 +23,11 @@ from grafeas.grafeas_v1.types import severity as g_severity
 
 
 __protobuf__ = proto.module(
-    package="grafeas.v1", manifest={"VulnerabilityNote", "VulnerabilityOccurrence",},
+    package="grafeas.v1",
+    manifest={
+        "VulnerabilityNote",
+        "VulnerabilityOccurrence",
+    },
 )
 
 
@@ -127,26 +131,66 @@ class VulnerabilityNote(proto.Message):
                 The name of the vendor of the product.
         """
 
-        severity_name = proto.Field(proto.STRING, number=1,)
-        description = proto.Field(proto.STRING, number=2,)
-        package_type = proto.Field(proto.STRING, number=3,)
-        affected_cpe_uri = proto.Field(proto.STRING, number=4,)
-        affected_package = proto.Field(proto.STRING, number=5,)
+        severity_name = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        description = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        package_type = proto.Field(
+            proto.STRING,
+            number=3,
+        )
+        affected_cpe_uri = proto.Field(
+            proto.STRING,
+            number=4,
+        )
+        affected_package = proto.Field(
+            proto.STRING,
+            number=5,
+        )
         affected_version_start = proto.Field(
-            proto.MESSAGE, number=6, message=package.Version,
+            proto.MESSAGE,
+            number=6,
+            message=package.Version,
         )
         affected_version_end = proto.Field(
-            proto.MESSAGE, number=7, message=package.Version,
+            proto.MESSAGE,
+            number=7,
+            message=package.Version,
+        )
+        fixed_cpe_uri = proto.Field(
+            proto.STRING,
+            number=8,
+        )
+        fixed_package = proto.Field(
+            proto.STRING,
+            number=9,
+        )
+        fixed_version = proto.Field(
+            proto.MESSAGE,
+            number=10,
+            message=package.Version,
+        )
+        is_obsolete = proto.Field(
+            proto.BOOL,
+            number=11,
         )
-        fixed_cpe_uri = proto.Field(proto.STRING, number=8,)
-        fixed_package = proto.Field(proto.STRING, number=9,)
-        fixed_version = proto.Field(proto.MESSAGE, number=10, message=package.Version,)
-        is_obsolete = proto.Field(proto.BOOL, number=11,)
         source_update_time = proto.Field(
-            proto.MESSAGE, number=12, message=timestamp_pb2.Timestamp,
+            proto.MESSAGE,
+            number=12,
+            message=timestamp_pb2.Timestamp,
+        )
+        source = proto.Field(
+            proto.STRING,
+            number=13,
+        )
+        vendor = proto.Field(
+            proto.STRING,
+            number=14,
         )
-        source = proto.Field(proto.STRING, number=13,)
-        vendor = proto.Field(proto.STRING, number=14,)
 
     class WindowsDetail(proto.Message):
         r"""
@@ -181,27 +225,61 @@ class VulnerabilityNote(proto.Message):
                     (https://www.catalog.update.microsoft.com/).
             """
 
-            name = proto.Field(proto.STRING, number=1,)
-            url = proto.Field(proto.STRING, number=2,)
+            name = proto.Field(
+                proto.STRING,
+                number=1,
+            )
+            url = proto.Field(
+                proto.STRING,
+                number=2,
+            )
 
-        cpe_uri = proto.Field(proto.STRING, number=1,)
-        name = proto.Field(proto.STRING, number=2,)
-        description = proto.Field(proto.STRING, number=3,)
+        cpe_uri = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        name = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        description = proto.Field(
+            proto.STRING,
+            number=3,
+        )
         fixing_kbs = proto.RepeatedField(
             proto.MESSAGE,
             number=4,
             message="VulnerabilityNote.WindowsDetail.KnowledgeBase",
         )
 
-    cvss_score = proto.Field(proto.FLOAT, number=1,)
-    severity = proto.Field(proto.ENUM, number=2, enum=g_severity.Severity,)
-    details = proto.RepeatedField(proto.MESSAGE, number=3, message=Detail,)
-    cvss_v3 = proto.Field(proto.MESSAGE, number=4, message=cvss.CVSSv3,)
+    cvss_score = proto.Field(
+        proto.FLOAT,
+        number=1,
+    )
+    severity = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=g_severity.Severity,
+    )
+    details = proto.RepeatedField(
+        proto.MESSAGE,
+        number=3,
+        message=Detail,
+    )
+    cvss_v3 = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=cvss.CVSSv3,
+    )
     windows_details = proto.RepeatedField(
-        proto.MESSAGE, number=5, message=WindowsDetail,
+        proto.MESSAGE,
+        number=5,
+        message=WindowsDetail,
     )
     source_update_time = proto.Field(
-        proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=6,
+        message=timestamp_pb2.Timestamp,
     )
 
 
@@ -296,32 +374,91 @@ class VulnerabilityOccurrence(proto.Message):
                 when it is not available.
         """
 
-        affected_cpe_uri = proto.Field(proto.STRING, number=1,)
-        affected_package = proto.Field(proto.STRING, number=2,)
+        affected_cpe_uri = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        affected_package = proto.Field(
+            proto.STRING,
+            number=2,
+        )
         affected_version = proto.Field(
-            proto.MESSAGE, number=3, message=package.Version,
+            proto.MESSAGE,
+            number=3,
+            message=package.Version,
+        )
+        fixed_cpe_uri = proto.Field(
+            proto.STRING,
+            number=4,
+        )
+        fixed_package = proto.Field(
+            proto.STRING,
+            number=5,
+        )
+        fixed_version = proto.Field(
+            proto.MESSAGE,
+            number=6,
+            message=package.Version,
+        )
+        fix_available = proto.Field(
+            proto.BOOL,
+            number=7,
+        )
+        package_type = proto.Field(
+            proto.STRING,
+            number=8,
         )
-        fixed_cpe_uri = proto.Field(proto.STRING, number=4,)
-        fixed_package = proto.Field(proto.STRING, number=5,)
-        fixed_version = proto.Field(proto.MESSAGE, number=6, message=package.Version,)
-        fix_available = proto.Field(proto.BOOL, number=7,)
-        package_type = proto.Field(proto.STRING, number=8,)
         effective_severity = proto.Field(
-            proto.ENUM, number=9, enum=g_severity.Severity,
+            proto.ENUM,
+            number=9,
+            enum=g_severity.Severity,
         )
 
-    type_ = proto.Field(proto.STRING, number=1,)
-    severity = proto.Field(proto.ENUM, number=2, enum=g_severity.Severity,)
-    cvss_score = proto.Field(proto.FLOAT, number=3,)
-    cvssv3 = proto.Field(proto.MESSAGE, number=10, message=cvss.CVSS,)
-    package_issue = proto.RepeatedField(proto.MESSAGE, number=4, message=PackageIssue,)
-    short_description = proto.Field(proto.STRING, number=5,)
-    long_description = proto.Field(proto.STRING, number=6,)
+    type_ = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    severity = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=g_severity.Severity,
+    )
+    cvss_score = proto.Field(
+        proto.FLOAT,
+        number=3,
+    )
+    cvssv3 = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        message=cvss.CVSS,
+    )
+    package_issue = proto.RepeatedField(
+        proto.MESSAGE,
+        number=4,
+        message=PackageIssue,
+    )
+    short_description = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    long_description = proto.Field(
+        proto.STRING,
+        number=6,
+    )
     related_urls = proto.RepeatedField(
-        proto.MESSAGE, number=7, message=common.RelatedUrl,
+        proto.MESSAGE,
+        number=7,
+        message=common.RelatedUrl,
+    )
+    effective_severity = proto.Field(
+        proto.ENUM,
+        number=8,
+        enum=g_severity.Severity,
+    )
+    fix_available = proto.Field(
+        proto.BOOL,
+        number=9,
     )
-    effective_severity = proto.Field(proto.ENUM, number=8, enum=g_severity.Severity,)
-    fix_available = proto.Field(proto.BOOL, number=9,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
